@@ -32,4 +32,4 @@ class Command(abc.ABC):
         pass
 
     def __should_run_help(self, args: List[str]) -> bool:
-        return len(args) > 0 and args[0] in ("-h", "h", "--help", "help")
+        return len(args) > 0 and args[0] in ("-h", "--help")
