@@ -40,7 +40,7 @@ class Main:
 
     def __log_user_command(self) -> None:
         args = subprocess.list2cmdline(self.__args)
-        self.__process.log_title(f"  {Emoji.BIN}  bin {args}")
+        self.__process.log_title(f"  {Emoji.BIN}  bin {args}\n")
 
 
 def main() -> None:
