@@ -12,7 +12,7 @@ class ShellRequirement(BinBaseModel, Requirement):
     help: Optional[str]
 
     def is_met(self, process: Process) -> bool:
-        return process.run(self.met_if_cmd).has_succeeded()
+        return process.run(self.met_if_cmd, capture_output=True).has_succeeded()
 
     def get_name(self) -> str:
         return self.name
